@@ -1,9 +1,10 @@
 package DB_File::Utils::Command::get;
-$DB_File::Utils::Command::get::VERSION = '0.001';
+$DB_File::Utils::Command::get::VERSION = '0.002';
 use v5.20;
 use DB_File::Utils -command;
 use strict;
 use warnings;
+use Encode qw'encode decode';
 
 use DB_File;
 use Fcntl;
@@ -14,10 +15,6 @@ sub description { "Given a DB_File with strings as keys, prints\nto standard out
 
 sub usage_desc { $_[0]->SUPER::usage_desc . ' <dbfile> <key>' }
 
-sub opt_spec {
-	return ();
-}
-
 sub validate_args {
 	my ($self, $opt, $args) = @_;
 
@@ -30,18 +27,22 @@ sub validate_args {
 sub execute {
 	my ($self, $opt, $args) = @_;
 
+	$opt = { %{$self->app->global_options}, %$opt};
+
 	my $file = $args->[0];
 	my $key  = $args->[1];
 
-	_retrieve($file, $key);
+	binmode STDOUT, ":utf8" if $opt->{utf8};
+
+	_retrieve($file, $key, $opt);
 }
 
 sub _retrieve {
-	my ($file, $key) = @_;
+	my ($file, $key, $opt) = @_;
 	my %hash;
 	tie %hash,  'DB_File', $file, O_RDWR, '0666', $DB_BTREE;
 	if (exists($hash{$key})) {
-		say $hash{$key};
+		say $opt->{utf8} ? decode('utf-8', $hash{$key}) : $hash{$key};
 	} else {
 		die "Key $key not found!"
 	}
